@@ -26,7 +26,7 @@
 #include "ConfigurationPage.h"
 
 #include "document/RosegardenGUIDoc.h"
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <tqwidget.h>
 #include <algorithm>
 
