@@ -26,7 +26,7 @@
 #include "AudioPluginDialog.h"
 #include <tqlayout.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include "misc/Debug.h"
 #include "misc/Strings.h"
 #include "base/AudioPluginInstance.h"
