@@ -37,8 +37,8 @@
 #include "TimeDialog.h"
 #include <kcombobox.h>
 #include <kdialogbase.h>
-#include <kfiledialog.h>
-#include <klocale.h>
+#include <tdefiledialog.h>
+#include <tdelocale.h>
 #include <tqcheckbox.h>
 #include <tqdialog.h>
 #include <tqfile.h>
