@@ -24,15 +24,15 @@
 
 
 #include "TextEventDialog.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include "misc/Strings.h"
 #include "document/ConfigGroups.h"
 #include "base/NotationTypes.h"
 #include "gui/editors/notation/NotePixmapFactory.h"
 #include <kcombobox.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kdialogbase.h>
 #include <tqbitmap.h>
 #include <tqgrid.h>
@@ -315,7 +315,7 @@ TextEventDialog::TextEventDialog(TQWidget *parent,
     m_staffBelowLabel->setPixmap(map);
 
     // restore last setting for shortcut combos
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup(NotationViewConfigGroup);
 
     m_dynamicShortcutCombo->setCurrentItem(config->readNumEntry("dynamic_shortcut", 0));
@@ -511,7 +511,7 @@ void
 TextEventDialog::slotOK()
 {
     // store last setting for shortcut combos
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup(NotationViewConfigGroup);
 
     config->writeEntry("dynamic_shortcut", m_dynamicShortcutCombo->currentItem());
