@@ -26,7 +26,7 @@
 #include "MatrixSelector.h"
 
 #include "base/BaseProperties.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstddirs.h>
 #include "base/Event.h"
 #include "base/NotationTypes.h"
@@ -46,10 +46,10 @@
 #include "MatrixStaff.h"
 #include "MatrixTool.h"
 #include "MatrixView.h"
-#include <kaction.h>
-#include <kglobal.h>
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeaction.h>
+#include <tdeglobal.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
 #include <tqdialog.h>
 #include <tqiconset.h>
 #include <tqpoint.h>
@@ -74,23 +74,23 @@ MatrixSelector::MatrixSelector(MatrixView* view)
     connect(m_parentView, TQT_SIGNAL(usedSelection()),
             this, TQT_SLOT(slotHideSelection()));
 
-    new KAction(i18n("Switch to Draw Tool"), "pencil", 0, this,
+    new TDEAction(i18n("Switch to Draw Tool"), "pencil", 0, this,
                 TQT_SLOT(slotDrawSelected()), actionCollection(),
                 "draw");
 
-    new KAction(i18n("Switch to Erase Tool"), "eraser", 0, this,
+    new TDEAction(i18n("Switch to Erase Tool"), "eraser", 0, this,
                 TQT_SLOT(slotEraseSelected()), actionCollection(),
                 "erase");
 
-    new KAction(i18n("Switch to Move Tool"), "move", 0, this,
+    new TDEAction(i18n("Switch to Move Tool"), "move", 0, this,
                 TQT_SLOT(slotMoveSelected()), actionCollection(),
                 "move");
 
-    TQString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
+    TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
     TQCanvasPixmap pixmap(pixmapDir + "/toolbar/resize.xpm");
     TQIconSet icon = TQIconSet(pixmap);
 
-    new KAction(i18n("Switch to Resize Tool"), icon, 0, this,
+    new TDEAction(i18n("Switch to Resize Tool"), icon, 0, this,
                 TQT_SLOT(slotResizeSelected()), actionCollection(),
                 "resize");
 
