@@ -25,7 +25,7 @@
 
 #include "NotationHLayout.h"
 #include "misc/Debug.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
 
 #include "base/Composition.h"
 #include "base/LayoutEngine.h"
@@ -46,7 +46,7 @@
 #include "NotationProperties.h"
 #include "NotationStaff.h"
 #include "NotePixmapFactory.h"
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <tqobject.h>
 #include <cmath>
 
@@ -75,7 +75,7 @@ NotationHLayout::NotationHLayout(Composition *c, NotePixmapFactory *npf,
 {
     //    NOTATION_DEBUG << "NotationHLayout::NotationHLayout()" << endl;
 
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup("Notation Options");
     m_keySigCancelMode = config->readNumEntry("keysigcancelmode", 1);
 }
@@ -255,7 +255,7 @@ NotationHLayout::scanStaff(Staff &staff, timeT startTime, timeT endTime)
 
     NOTATION_DEBUG << "ottava shift at start:" << ottavaShift << ", ottavaEnd " << ottavaEnd << endl;
 
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup("Notation Options");
 
     int accOctaveMode = config->readNumEntry("accidentaloctavemode", 1);
@@ -1266,7 +1266,7 @@ NotationHLayout::layout(BarDataMap::iterator i, timeT startTime, timeT endTime)
 
     int startBar = getComposition()->getBarNumber(startTime);
 
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup("Notation Options");
     bool showInvisibles = config->readBoolEntry("showinvisibles", true);
 
