@@ -26,7 +26,7 @@
 #include "NotationVLayout.h"
 #include "misc/Debug.h"
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include "base/Composition.h"
 #include "base/Event.h"
 #include "base/LayoutEngine.h"
@@ -41,7 +41,7 @@
 #include "NotationProperties.h"
 #include "NotationStaff.h"
 #include "NotePixmapFactory.h"
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <tqobject.h>
 #include <tqstring.h>
 #include <tqwidget.h>
