@@ -25,7 +25,7 @@
 
 #include "TempoView.h"
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstddirs.h>
 #include "misc/Debug.h"
 #include "base/Composition.h"
@@ -44,10 +44,10 @@
 #include "gui/general/EditViewBase.h"
 #include "gui/kdeext/KTmpStatusMsg.h"
 #include "TempoListItem.h"
-#include <kaction.h>
-#include <kglobal.h>
-#include <kconfig.h>
-#include <klistview.h>
+#include <tdeaction.h>
+#include <tdeglobal.h>
+#include <tdeconfig.h>
+#include <tdelistview.h>
 #include <kxmlguiclient.h>
 #include <tqbuttongroup.h>
 #include <tqcheckbox.h>
@@ -97,7 +97,7 @@ TempoView::TempoView(RosegardenGUIDoc *doc, TQWidget *parent, timeT openTime):
     connect(m_filterGroup, TQT_SIGNAL(released(int)),
             TQT_SLOT(slotModifyFilter(int)));
 
-    m_list = new KListView(getCentralWidget());
+    m_list = new TDEListView(getCentralWidget());
     m_list->setItemsRenameable(true);
 
     m_grid->addWidget(m_list, 2, 1);
@@ -575,51 +575,51 @@ TempoView::setupActions()
 {
     EditViewBase::setupActions("tempoview.rc", false);
 
-    TQString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
+    TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
     TQIconSet icon(TQPixmap(pixmapDir + "/toolbar/event-insert-tempo.png"));
 
-    new KAction(AddTempoChangeCommand::getGlobalName(), icon, Key_I, TQT_TQOBJECT(this),
+    new TDEAction(AddTempoChangeCommand::getGlobalName(), icon, Key_I, TQT_TQOBJECT(this),
                 TQT_SLOT(slotEditInsertTempo()), actionCollection(),
                 "insert_tempo");
 
     TQCanvasPixmap pixmap(pixmapDir + "/toolbar/event-insert-timesig.png");
     icon = TQIconSet(pixmap);
 
-    new KAction(AddTimeSignatureCommand::getGlobalName(), icon, Key_G, TQT_TQOBJECT(this),
+    new TDEAction(AddTimeSignatureCommand::getGlobalName(), icon, Key_G, TQT_TQOBJECT(this),
                 TQT_SLOT(slotEditInsertTimeSignature()), actionCollection(),
                 "insert_timesig");
 
     pixmap.load(pixmapDir + "/toolbar/event-delete.png");
     icon = TQIconSet(pixmap);
 
-    new KAction(i18n("&Delete"), icon, Key_Delete, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Delete"), icon, Key_Delete, TQT_TQOBJECT(this),
                 TQT_SLOT(slotEditDelete()), actionCollection(),
                 "delete");
 
     pixmap.load(pixmapDir + "/toolbar/event-edit.png");
     icon = TQIconSet(pixmap);
 
-    new KAction(i18n("&Edit Item"), icon, Key_E, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Edit Item"), icon, Key_E, TQT_TQOBJECT(this),
                 TQT_SLOT(slotEdit()), actionCollection(),
                 "edit");
 
-    new KAction(i18n("Select &All"), 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Select &All"), 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotSelectAll()), actionCollection(),
                 "select_all");
 
-    new KAction(i18n("Clear Selection"), Key_Escape, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Clear Selection"), Key_Escape, TQT_TQOBJECT(this),
                 TQT_SLOT(slotClearSelection()), actionCollection(),
                 "clear_selection");
 
     m_config->setGroup(TempoViewConfigGroup);
     int timeMode = m_config->readNumEntry("timemode", 0);
 
-    KRadioAction *action;
+    TDERadioAction *action;
 
     pixmap.load(pixmapDir + "/toolbar/time-musical.png");
     icon = TQIconSet(pixmap);
 
-    action = new KRadioAction(i18n("&Musical Times"), icon, 0, TQT_TQOBJECT(this),
+    action = new TDERadioAction(i18n("&Musical Times"), icon, 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotMusicalTime()),
                               actionCollection(), "time_musical");
     action->setExclusiveGroup("timeMode");
@@ -629,7 +629,7 @@ TempoView::setupActions()
     pixmap.load(pixmapDir + "/toolbar/time-real.png");
     icon = TQIconSet(pixmap);
 
-    action = new KRadioAction(i18n("&Real Times"), icon, 0, TQT_TQOBJECT(this),
+    action = new TDERadioAction(i18n("&Real Times"), icon, 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotRealTime()),
                               actionCollection(), "time_real");
     action->setExclusiveGroup("timeMode");
@@ -639,7 +639,7 @@ TempoView::setupActions()
     pixmap.load(pixmapDir + "/toolbar/time-raw.png");
     icon = TQIconSet(pixmap);
 
-    action = new KRadioAction(i18n("Ra&w Times"), icon, 0, TQT_TQOBJECT(this),
+    action = new TDERadioAction(i18n("Ra&w Times"), icon, 0, TQT_TQOBJECT(this),
                               TQT_SLOT(slotRawTime()),
                               actionCollection(), "time_raw");
     action->setExclusiveGroup("timeMode");
