@@ -27,8 +27,8 @@
 #include <tqlayout.h>
 
 #include "base/BaseProperties.h"
-#include <klocale.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
 #include "misc/Debug.h"
 #include "misc/Strings.h"
 #include "ActiveItem.h"
@@ -79,10 +79,10 @@
 #include "gui/rulers/ControlRuler.h"
 #include "gui/rulers/PropertyControlRuler.h"
 #include "RosegardenCanvasView.h"
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kcommand.h>
 #include <kdockwidget.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <kiconloader.h>
 #include <kstddirs.h>
 #include <ktabwidget.h>
@@ -360,7 +360,7 @@ void EditView::addPropertyBox(TQWidget *w)
 void EditView::addControlRuler(ControlRuler* ruler)
 {
     ruler->setWorldMatrix(m_currentRulerZoomMatrix);
-    m_controlRulers->addTab(ruler, KGlobal::iconLoader()->loadIconSet("fileclose", KIcon::Small),
+    m_controlRulers->addTab(ruler, TDEGlobal::iconLoader()->loadIconSet("window-close", TDEIcon::Small),
                             ruler->getName());
     m_controlRulers->showPage(ruler);
 
@@ -723,17 +723,17 @@ EditView::setupActions()
     //
     // Tempo and time signature changes
     //
-    TQString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
+    TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
     TQCanvasPixmap pixmap(pixmapDir + "/toolbar/event-insert-tempo.png");
     TQIconSet icon = TQIconSet(pixmap);
-    new KAction(AddTempoChangeCommand::getGlobalName(),
+    new TDEAction(AddTempoChangeCommand::getGlobalName(),
 		icon, 0,
 		TQT_TQOBJECT(this), TQT_SLOT(slotAddTempo()),
 		actionCollection(), "add_tempo");
 
     pixmap.load(pixmapDir + "/toolbar/event-insert-timesig.png");
     icon = TQIconSet(pixmap);
-    new KAction(AddTimeSignatureCommand::getGlobalName(),
+    new TDEAction(AddTimeSignatureCommand::getGlobalName(),
 		icon, 0,
 		TQT_TQOBJECT(this), TQT_SLOT(slotAddTimeSignature()),
 		actionCollection(), "add_time_signature");
@@ -741,118 +741,118 @@ EditView::setupActions()
     //
     // Transforms
     //
-    new KAction(i18n("&Halve Durations"), Key_H + CTRL, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Halve Durations"), Key_H + CTRL, TQT_TQOBJECT(this),
                 TQT_SLOT(slotHalveDurations()), actionCollection(),
                 "halve_durations");
 
-    new KAction(i18n("&Double Durations"), Key_H + CTRL + SHIFT, TQT_TQOBJECT(this),
+    new TDEAction(i18n("&Double Durations"), Key_H + CTRL + SHIFT, TQT_TQOBJECT(this),
                 TQT_SLOT(slotDoubleDurations()), actionCollection(),
                 "double_durations");
 
-    new KAction(RescaleCommand::getGlobalName(), 0, TQT_TQOBJECT(this),
+    new TDEAction(RescaleCommand::getGlobalName(), 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotRescale()), actionCollection(),
                 "rescale");
 
-    new KAction(TransposeCommand::getGlobalName(1), 0,
+    new TDEAction(TransposeCommand::getGlobalName(1), 0,
                 Key_Up, TQT_TQOBJECT(this),
                 TQT_SLOT(slotTransposeUp()), actionCollection(),
                 "transpose_up");
 
-    new KAction(TransposeCommand::getGlobalName(12), 0,
+    new TDEAction(TransposeCommand::getGlobalName(12), 0,
                 Key_Up + CTRL, TQT_TQOBJECT(this),
                 TQT_SLOT(slotTransposeUpOctave()), actionCollection(),
                 "transpose_up_octave");
 
-    new KAction(TransposeCommand::getGlobalName( -1), 0,
+    new TDEAction(TransposeCommand::getGlobalName( -1), 0,
                 Key_Down, TQT_TQOBJECT(this),
                 TQT_SLOT(slotTransposeDown()), actionCollection(),
                 "transpose_down");
 
-    new KAction(TransposeCommand::getGlobalName( -12), 0,
+    new TDEAction(TransposeCommand::getGlobalName( -12), 0,
                 Key_Down + CTRL, TQT_TQOBJECT(this),
                 TQT_SLOT(slotTransposeDownOctave()), actionCollection(),
                 "transpose_down_octave");
 
-    new KAction(TransposeCommand::getGlobalName(0), 0, TQT_TQOBJECT(this),
+    new TDEAction(TransposeCommand::getGlobalName(0), 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotTranspose()), actionCollection(),
                 "general_transpose");
 
-    new KAction(TransposeCommand::getDiatonicGlobalName(0,0), 0, TQT_TQOBJECT(this),
+    new TDEAction(TransposeCommand::getDiatonicGlobalName(0,0), 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotDiatonicTranspose()), actionCollection(),
                 "general_diatonic_transpose");
 
-    new KAction(InvertCommand::getGlobalName(0), 0, TQT_TQOBJECT(this),
+    new TDEAction(InvertCommand::getGlobalName(0), 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotInvert()), actionCollection(),
                 "invert");
 
-    new KAction(RetrogradeCommand::getGlobalName(0), 0, TQT_TQOBJECT(this),
+    new TDEAction(RetrogradeCommand::getGlobalName(0), 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotRetrograde()), actionCollection(),
                 "retrograde");
 
-    new KAction(RetrogradeInvertCommand::getGlobalName(0), 0, TQT_TQOBJECT(this),
+    new TDEAction(RetrogradeInvertCommand::getGlobalName(0), 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotRetrogradeInvert()), actionCollection(),
                 "retrograde_invert");
 
-    new KAction(i18n("Jog &Left"), Key_Left + ALT, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Jog &Left"), Key_Left + ALT, TQT_TQOBJECT(this),
                 TQT_SLOT(slotJogLeft()), actionCollection(),
                 "jog_left");
 
-    new KAction(i18n("Jog &Right"), Key_Right + ALT, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Jog &Right"), Key_Right + ALT, TQT_TQOBJECT(this),
                 TQT_SLOT(slotJogRight()), actionCollection(),
                 "jog_right");
 
     // Control rulers
     //
-    new KAction(i18n("Show Velocity Property Ruler"), 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Show Velocity Property Ruler"), 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotShowVelocityControlRuler()), actionCollection(),
                 "show_velocity_control_ruler");
 
     /*
-    new KAction(i18n("Show Controllers Events Ruler"), 0, this,
+    new TDEAction(i18n("Show Controllers Events Ruler"), 0, this,
                 TQT_SLOT(slotShowControllerEventsRuler()), actionCollection(),
                 "show_controller_events_ruler");
                 */
 
     // Disabled for now
     //
-    //     new KAction(i18n("Add Control Ruler..."), 0, this,
+    //     new TDEAction(i18n("Add Control Ruler..."), 0, this,
     //                 TQT_SLOT(slotShowPropertyControlRuler()), actionCollection(),
     //                 "add_control_ruler");
 
     //
     // Control Ruler context menu
     //
-    new KAction(i18n("Insert item"), 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Insert item"), 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotInsertControlRulerItem()), actionCollection(),
                 "insert_control_ruler_item");
 
     // This was on Key_Delete, but that conflicts with existing Delete commands
     // on individual edit views
-    new KAction(i18n("Erase selected items"), 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Erase selected items"), 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotEraseControlRulerItem()), actionCollection(),
                 "erase_control_ruler_item");
 
-    new KAction(i18n("Clear ruler"), 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Clear ruler"), 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotClearControlRulerItem()), actionCollection(),
                 "clear_control_ruler_item");
 
-    new KAction(i18n("Insert line of controllers"), 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Insert line of controllers"), 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotStartControlLineItem()), actionCollection(),
                 "start_control_line_item");
 
-    new KAction(i18n("Flip forward"), Key_BracketRight, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Flip forward"), Key_BracketRight, TQT_TQOBJECT(this),
                 TQT_SLOT(slotFlipForwards()), actionCollection(),
                 "flip_control_events_forward");
 
-    new KAction(i18n("Flip backwards"), Key_BracketLeft, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Flip backwards"), Key_BracketLeft, TQT_TQOBJECT(this),
                 TQT_SLOT(slotFlipBackwards()), actionCollection(),
                 "flip_control_events_back");
 
-    new KAction(i18n("Draw property line"), 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Draw property line"), 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotDrawPropertyLine()), actionCollection(),
                 "draw_property_line");
 
-    new KAction(i18n("Select all property values"), 0, TQT_TQOBJECT(this),
+    new TDEAction(i18n("Select all property values"), 0, TQT_TQOBJECT(this),
                 TQT_SLOT(slotSelectAllProperties()), actionCollection(),
                 "select_all_properties");
 }
@@ -1081,26 +1081,26 @@ EditView::createInsertPitchActionMenu()
                                         },
                                     };
 
-    KActionMenu *insertPitchActionMenu =
-        new KActionMenu(i18n("&Insert Note"), TQT_TQOBJECT(this), "insert_note_actionmenu");
+    TDEActionMenu *insertPitchActionMenu =
+        new TDEActionMenu(i18n("&Insert Note"), TQT_TQOBJECT(this), "insert_note_actionmenu");
 
     for (int octave = 0; octave <= 2; ++octave) {
 
-        KActionMenu *menu = insertPitchActionMenu;
+        TDEActionMenu *menu = insertPitchActionMenu;
         if (octave == 1) {
-            menu = new KActionMenu(i18n("&Upper Octave"), TQT_TQOBJECT(this),
+            menu = new TDEActionMenu(i18n("&Upper Octave"), TQT_TQOBJECT(this),
                                    "insert_note_actionmenu_upper_octave");
-            insertPitchActionMenu->insert(new KActionSeparator(TQT_TQOBJECT(this)));
+            insertPitchActionMenu->insert(new TDEActionSeparator(TQT_TQOBJECT(this)));
             insertPitchActionMenu->insert(menu);
         } else if (octave == 2) {
-            menu = new KActionMenu(i18n("&Lower Octave"), TQT_TQOBJECT(this),
+            menu = new TDEActionMenu(i18n("&Lower Octave"), TQT_TQOBJECT(this),
                                    "insert_note_actionmenu_lower_octave");
             insertPitchActionMenu->insert(menu);
         }
 
         for (unsigned int i = 0; i < 7; ++i) {
 
-            KAction *insertPitchAction = 0;
+            TDEAction *insertPitchAction = 0;
 
             TQString octaveSuffix;
             if (octave == 1)
@@ -1113,7 +1113,7 @@ EditView::createInsertPitchActionMenu()
             if (i != 0 && i != 3) {
 
                 insertPitchAction =
-                    new KAction
+                    new TDEAction
                     (flat.arg(notePitchNames[i]),
                      CTRL + SHIFT + notePitchKeys[octave][i],
                      TQT_TQOBJECT(this), TQT_SLOT(slotInsertNoteFromAction()), actionCollection(),
@@ -1123,7 +1123,7 @@ EditView::createInsertPitchActionMenu()
             }
 
             insertPitchAction =
-                new KAction
+                new TDEAction
                 (notePitchNames[i],
                  notePitchKeys[octave][i],
                  TQT_TQOBJECT(this), TQT_SLOT(slotInsertNoteFromAction()), actionCollection(),
@@ -1136,7 +1136,7 @@ EditView::createInsertPitchActionMenu()
             if (i != 2 && i != 6) {
 
                 insertPitchAction =
-                    new KAction
+                    new TDEAction
                     (sharp.arg(notePitchNames[i]),
                      SHIFT + notePitchKeys[octave][i],
                      TQT_TQOBJECT(this), TQT_SLOT(slotInsertNoteFromAction()), actionCollection(),
@@ -1146,7 +1146,7 @@ EditView::createInsertPitchActionMenu()
             }
 
             if (i < 6)
-                menu->insert(new KActionSeparator(TQT_TQOBJECT(this)));
+                menu->insert(new TDEActionSeparator(TQT_TQOBJECT(this)));
         }
     }
 
@@ -1350,7 +1350,7 @@ void EditView::slotShowPropertyControlRuler()
         KDialogBase propChooserDialog(this, "propertychooserdialog", true, i18n("Select event property"),
                                       KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok);
         
-        KListBox* propList = new KListBox(propChooserDialog.makeVBoxMainWidget());
+        TDEListBox* propList = new TDEListBox(propChooserDialog.makeVBoxMainWidget());
         new TQListBoxRGProperty(propList, BaseProperties::VELOCITY.c_str());
      
         int rc = propChooserDialog.exec();
