@@ -34,9 +34,9 @@
 #include "base/MidiProgram.h"
 #include "gui/widgets/RosegardenPopupMenu.h"
 #include <kcompletion.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <klineedit.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstddirs.h>
 #include <tqcheckbox.h>
 #include <tqcursor.h>
@@ -222,7 +222,7 @@ MidiProgramsEditor::populate(TQListViewItem* item)
     ProgramList::iterator it;
 
     TQPixmap noKeyPixmap, keyPixmap;
-    TQString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
+    TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
     TQString file = pixmapDir + "/toolbar/key-white.png";
     if (TQFile(file).exists())
         noKeyPixmap = TQPixmap(file);
@@ -521,7 +521,7 @@ MidiProgramsEditor::slotEntryMenuItemSelected(int i)
     }
 
     m_device->setKeyMappingForProgram(*program, newMapping);
-    TQString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
+    TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
     bool haveKeyMappings = (m_device->getKeyMappings().size() > 0);
     TQPushButton *btn = getEntryButton(m_currentMenuProgram);
 
