@@ -20,7 +20,7 @@
 
 #include <cmath>
 #include <cstdlib>
-#include <kapplication.h>
+#include <tdeapplication.h>
 
 #include <tqdatetime.h>
 #include <tqstringlist.h>
